==> haskell-pandoc_3.1.11.1.orig.tar.gz: pandoc-3.1.11.1/test/command/2649.md <==
```
% pandoc -f mediawiki -t html5
{| class="wikitable" style="line-height: 1.0"

|- bgcolor="#efefef"
|}
^D
<table>
<tbody>
<tr class="odd">
</tr>
</tbody>
</table>
```

```
% pandoc -f mediawiki -t html5
{| border="4" cellspacing="2" cellpadding="0" WIDTH="100%"
|-----
| peildatum Simbase || november 2005 || colspan=2 | '''uitslagen Flohrgambiet''' ||
|-----
| totaal aantal partijen Simbase || 7.316.773
| wit wint || 53%
|-----
| percentage (en partijen) Flohrgambiet
| 0.023 % (1.699) || zwart wint || 27%
|-----
| percentage Flohrgambiet in aug 2003
| 0.035 % || remise || 20%
|}
^D
<table>
<tbody>
<tr class="odd">
<td><p>peildatum Simbase</p></td>
<td><p>november 2005</p></td>
<td colspan="2"><p><strong>uitslagen Flohrgambiet</strong></p></td>
</tr>
<tr class="even">
<td><p>totaal aantal partijen Simbase</p></td>
<td><p>7.316.773</p></td>
<td><p>wit wint</p></td>
<td><p>53%</p></td>
</tr>
<tr class="odd">
<td><p>percentage (en partijen) Flohrgambiet</p></td>
<td><p>0.023 % (1.699)</p></td>
<td><p>zwart wint</p></td>
<td><p>27%</p></td>
</tr>
<tr class="even">
<td><p>percentage Flohrgambiet in aug 2003</p></td>
<td><p>0.035 %</p></td>
<td><p>remise</p></td>
<td><p>20%</p></td>
</tr>
</tbody>
</table>
```

```
% pandoc -f mediawiki -t html5
{| class="wikitable" style="text-align:center; font-size:95%" valign="top" |
! Plaats
! Rijder
! Aantal
|-
| 1
|align=left| {{FR-VLAG}} [[Sébastien Loeb]]
| 78
|-
| 2
|align=left| {{FR-VLAG}} '''[[Sébastien Ogier]]'''
| 38
|-
| 10
|align=left| {{FI-VLAG}} [[Hannu Mikkola]]
| 18
|}
^D
<table>
<thead>
<tr class="header">
<th><p>Plaats</p></th>
<th><p>Rijder</p></th>
<th><p>Aantal</p></th>
</tr>
</thead>
<tbody>
<tr class="odd">
<td><p>1</p></td>
<td style="text-align: left;"><p><a href="Sébastien_Loeb"
title="wikilink">Sébastien Loeb</a></p></td>
<td><p>78</p></td>
</tr>
<tr class="even">
<td><p>2</p></td>
<td style="text-align: left;"><p><strong><a href="Sébastien_Ogier"
title="wikilink">Sébastien Ogier</a></strong></p></td>
<td><p>38</p></td>
</tr>
<tr class="odd">
<td><p>10</p></td>
<td style="text-align: left;"><p><a href="Hannu_Mikkola"
title="wikilink">Hannu Mikkola</a></p></td>
<td><p>18</p></td>
</tr>
</tbody>
</table>
```

==> haskell-pandoc_3.7.0.2.orig.tar.gz: pandoc-3.7.0.2/test/command/2649.md <==
```
% pandoc -f mediawiki -t html5
{| class="wikitable" style="line-height: 1.0"

|- bgcolor="#efefef"
|}
^D
<table>
<tbody>
<tr>
</tr>
</tbody>
</table>
```

```
% pandoc -f mediawiki -t html5
{| border="4" cellspacing="2" cellpadding="0" WIDTH="100%"
|-----
| peildatum Simbase || november 2005 || colspan=2 | '''uitslagen Flohrgambiet'''
|-----
| totaal aantal partijen Simbase || 7.316.773
| wit wint || 53%
|-----
| percentage (en partijen) Flohrgambiet
| 0.023 % (1.699) || zwart wint || 27%
|-----
| percentage Flohrgambiet in aug 2003
| 0.035 % || remise || 20%
|}
^D
<table>
<tbody>
<tr>
<td><p>peildatum Simbase</p></td>
<td><p>november 2005</p></td>
<td colspan="2"><p><strong>uitslagen Flohrgambiet</strong></p></td>
</tr>
<tr>
<td><p>totaal aantal partijen Simbase</p></td>
<td><p>7.316.773</p></td>
<td><p>wit wint</p></td>
<td><p>53%</p></td>
</tr>
<tr>
<td><p>percentage (en partijen) Flohrgambiet</p></td>
<td><p>0.023 % (1.699)</p></td>
<td><p>zwart wint</p></td>
<td><p>27%</p></td>
</tr>
<tr>
<td><p>percentage Flohrgambiet in aug 2003</p></td>
<td><p>0.035 %</p></td>
<td><p>remise</p></td>
<td><p>20%</p></td>
</tr>
</tbody>
</table>
```

```
% pandoc -f mediawiki -t html5
{| class="wikitable" style="text-align:center; font-size:95%" valign="top" |
! Plaats
! Rijder
! Aantal
|-
| 1
|align=left| {{FR-VLAG}} [[Sébastien Loeb]]
| 78
|-
| 2
|align=left| {{FR-VLAG}} '''[[Sébastien Ogier]]'''
| 38
|-
| 10
|align=left| {{FI-VLAG}} [[Hannu Mikkola]]
| 18
|}
^D
<table>
<thead>
<tr>
<th><p>Plaats</p></th>
<th><p>Rijder</p></th>
<th><p>Aantal</p></th>
</tr>
</thead>
<tbody>
<tr>
<td><p>1</p></td>
<td style="text-align: left;"><p><a href="Sébastien_Loeb"
class="wikilink" title="Sébastien Loeb">Sébastien Loeb</a></p></td>
<td><p>78</p></td>
</tr>
<tr>
<td><p>2</p></td>
<td style="text-align: left;"><p><strong><a href="Sébastien_Ogier"
class="wikilink" title="Sébastien Ogier">Sébastien
Ogier</a></strong></p></td>
<td><p>38</p></td>
</tr>
<tr>
<td><p>10</p></td>
<td style="text-align: left;"><p><a href="Hannu_Mikkola"
class="wikilink" title="Hannu Mikkola">Hannu Mikkola</a></p></td>
<td><p>18</p></td>
</tr>
</tbody>
</table>
```
